@@ -387,6 +387,7 @@ gail_finish_select (GtkWidget *widget)
           void *vp_next_focus_widget = &next_focus_widget;
           g_source_remove (focus_notify_handler);
           g_object_remove_weak_pointer (G_OBJECT (next_focus_widget), vp_next_focus_widget);
+	  next_focus_widget = NULL;
           focus_notify_handler = 0;
           was_deselect = FALSE;
         }
@@ -618,6 +619,7 @@ gail_focus_notify_when_idle (GtkWidget *widget)
 	    {
 	      void *vp_next_focus_widget = &next_focus_widget;
 	      g_object_remove_weak_pointer (G_OBJECT (next_focus_widget), vp_next_focus_widget);
+	      next_focus_widget = NULL;
 	    }
         }
       else
@@ -683,6 +685,7 @@ gail_deactivate_watcher (GSignalInvocationHint *ihint,
       void *vp_next_focus_widget = &next_focus_widget;
       g_source_remove (focus_notify_handler);
       g_object_remove_weak_pointer (G_OBJECT (next_focus_widget), vp_next_focus_widget);
+      next_focus_widget = NULL;
       focus_notify_handler = 0;
       was_deselect = FALSE;
     }
@@ -923,6 +926,7 @@ gail_accessibility_module_init (void)
 
   /* Initialize the GailUtility class */
   g_type_class_unref (g_type_class_ref (GAIL_TYPE_UTIL));
+  g_type_class_unref (g_type_class_ref (GAIL_TYPE_MISC));
 }
 
 /**
